**Example 1: 修改子应用状态**



Input: 

```
tccli vod ModifySubAppIdStatus --cli-unfold-argument  \
    --SubAppId 1400000001 \
    --Status Off
```

Output: 
```
{
    "Response": {
        "RequestId": "12ae8d8e-dce3-4151-9d4b-5594145287e1"
    }
}
```

